==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebDragServiceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDragServiceDescription } from "./WebDragServiceDescription";
/**
 * @hidden
 */
export let WebDragServiceDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDragServiceDescriptionMetadata extends Base {
        static b(a) {
            if (WebDragServiceDescriptionMetadata.a == null) {
                WebDragServiceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDragServiceDescriptionMetadata.c(WebDragServiceDescriptionMetadata.a);
            }
            if (a.k(WebDragServiceDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebDragServiceDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DragService");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebDragServiceDescriptionMetadata.b(a);
            a.ac("WebDragService", () => new WebDragServiceDescription());
            a.ab("WebDragService", WebDragServiceDescriptionMetadata.a);
        }
    }
    WebDragServiceDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDragServiceDescriptionMetadata, 'WebDragServiceDescriptionMetadata');
    WebDragServiceDescriptionMetadata.a = null;
    return WebDragServiceDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebDragServiceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDragServiceDescription } from "./WebDragServiceDescription";
/**
 * @hidden
 */
export let WebDragServiceDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDragServiceDescriptionMetadata extends Base {
        static b(a) {
            if (WebDragServiceDescriptionMetadata.a == null) {
                WebDragServiceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDragServiceDescriptionMetadata.c(WebDragServiceDescriptionMetadata.a);
            }
            if (a.k(WebDragServiceDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebDragServiceDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DragService");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebDragServiceDescriptionMetadata.b(a);
            a.ae("WebDragService", () => new WebDragServiceDescription());
            a.ad("WebDragService", WebDragServiceDescriptionMetadata.a);
        }
    }
    WebDragServiceDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDragServiceDescriptionMetadata, 'WebDragServiceDescriptionMetadata');
    WebDragServiceDescriptionMetadata.a = null;
    return WebDragServiceDescriptionMetadata;
})();
